==> nextcloud-18.0.4.tgz: nextcloud/apps/twofactor_backupcodes/l10n/eu.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Zure kontuarentzat bai faktoreko segurtasun kodeak sortu dituzu",
    "Second-factor backup codes" : "Bigarren faktoreko segurtasun kodeak",
    "Generate backup codes" : "Segurtasun kodeak sortu",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Bi faktoreko autentifikazioa aktibatu duzu baina ez duzu segurtasun koderik sortu oraindik. Bigarren faktorea galtzen baduzu zure kontura sartu ahal izateko beharrezkoak dira segurtasun kode horiek.",
    "Backup code" : "Babeskopia-kodea",
    "Use backup code" : "Erabili ordezko kodea",
    "Two factor backup codes" : "Bigarren faktoreko segurtasun kodeak",
    "A two-factor auth backup codes provider" : "Bigarren faktoreko segurtasun kodeen hornitzailea",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Sortu den segurtasun kode kopurua. {used} erabili dira {total} segurtasun kodetik.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Hauexek dira zure segurtasun kodeak. Gorde edo/eta inprimatu itzazu ez baitira berriz agertuko.",
    "Save backup codes" : "Gorde babeskopia-kodeak",
    "Print backup codes" : "Segurtasun kodeak inprimatu",
    "Regenerate backup codes" : "Segurtasun kodeak berriz sortu",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Segurtasun kodeak berriz sortzen badituzu, zaharrak desaktibatu egingo dira.",
    "An error occurred while generating your backup codes" : "Errorea gertatu da segurtasun kodeak sortzean",
    "{name} backup codes" : "{name} segurtasun kodeak",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Erabili bi faktoreko autentifikazioa aktibatu zenuenean sortutako segurtasun kodeetako bat",
    "Submit" : "Bidali",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","segurtasun-kodeak-sortu"],
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Bi faktoreko autentifikazioa aktibatu duzu baina ez duzu segurtasun koderik sortu oraindik. Bigarren faktorea galtzen baduzu zure kontura sartu ahal izateko beharrezkoak dira segurtasun kode horiek.",
    "function" : "funtzioa"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.8.tgz: nextcloud/apps/twofactor_backupcodes/l10n/eu.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Zure kontuarentzat bai faktoreko segurtasun kodeak sortu dituzu",
    "Second-factor backup codes" : "Bigarren faktoreko segurtasun kodeak",
    "Generate backup codes" : "Segurtasun kodeak sortu",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Bi faktoreko autentifikazioa aktibatu duzu baina ez duzu segurtasun koderik sortu oraindik. Bigarren faktorea galtzen baduzu zure kontura sartu ahal izateko beharrezkoak dira segurtasun kode horiek.",
    "Backup code" : "Babeskopia-kodea",
    "Use backup code" : "Erabili ordezko kodea",
    "Two factor backup codes" : "Bigarren faktoreko segurtasun kodeak",
    "A two-factor auth backup codes provider" : "Bigarren faktoreko segurtasun kodeen hornitzailea",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Sortu den segurtasun kode kopurua. {used} erabili dira {total} segurtasun kodetik.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Hauexek dira zure segurtasun kodeak. Gorde edo/eta inprimatu itzazu ez baitira berriz agertuko.",
    "Save backup codes" : "Gorde babeskopia-kodeak",
    "Print backup codes" : "Segurtasun kodeak inprimatu",
    "Regenerate backup codes" : "Segurtasun kodeak berriz sortu",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Segurtasun kodeak berriz sortzen badituzu, zaharrak desaktibatu egingo dira.",
    "An error occurred while generating your backup codes" : "Errorea gertatu da segurtasun kodeak sortzean",
    "{name} backup codes" : "{name} segurtasun kodeak",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Erabili bi faktoreko autentifikazioa aktibatu zenuenean sortutako segurtasun kodeetako bat",
    "Submit" : "Bidali",
    "function" : "funtzioa",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","segurtasun-kodeak-sortu"]
},
"nplurals=2; plural=(n != 1);");
